@@ -49,7 +49,6 @@ from pitivi.utils.misc import path_from_uri
 
 # Dimensions in pixels
 EXPANDED_SIZE = 65
-CONTROL_WIDTH = 240
 
 PADDING = 6
 SPACING = 10
@@ -59,6 +58,12 @@ PLAYHEAD_COLOR = (255, 0, 0)
 SNAPBAR_WIDTH = 5
 SNAPBAR_COLOR = (127, 153, 204)
 LAYER_HEIGHT = 130
+# The space between two layers.
+SEPARATOR_HEIGHT = PADDING
+
+SMALL_THUMB_WIDTH = 64
+# 128 is the normal size for thumbnails, but for *icons* it looks insane.
+LARGE_THUMB_WIDTH = 96
 
 # Drag and drop
 FILE_TARGET_ENTRY = Gtk.TargetEntry.new("text/plain", 0, 0)
@@ -124,39 +129,30 @@ TIMELINE_CSS = """
     }
 
     .Trimbar:hover {
-         background-image: url('%(trimbar_focused)s');
+        background-image: url('%(trimbar_focused)s');
     }
 
     .Clip {
-    /* TODO */
     }
 
     .TransitionClip {
-         background-color: rgba(127, 153, 204, 0.5);
+        background-color: rgba(127, 153, 204, 0.5);
     }
 
     .TransitionClip:selected {
-         background-color: rgba(127, 200, 204, 0.7);
+        background-color: rgba(127, 200, 204, 0.7);
     }
 
     .SpacedSeparator:hover {
         background-color: rgba(127, 153, 204, 0.5);
-        opacity:0.5;
     }
 
     .SpacedSeparator {
-        background-color: rgba(0, 0, 0, 0.10);
-        border-bottom-color: rgba(0, 0, 0, 0.10);
-        border-left-color: rgba(0, 0, 0, 0.10);
-        border-right-color: rgba(0, 0, 0, 0.10);
-        border-top-color: rgba(0, 0, 0, 0.10);
-        color: rgba(0, 0, 0, 0.10);
-        outline-color: rgba(238, 238, 236, 0.29);
-        opacity:1;
+        background-color: rgba(0, 0, 0, 0.1);
     }
 
     .Marquee {
-         background-color: rgba(224, 224, 224, 0.7);
+        background-color: rgba(224, 224, 224, 0.7);
     }
 
 """ % ({'trimbar_normal': os.path.join(get_pixmap_dir(), "trimbar-normal.png"),
@@ -354,6 +350,7 @@ def time_to_string(value):
     """
     if value == Gst.CLOCK_TIME_NONE:
         return "--:--:--.---"
+
     ms = value / Gst.MSECOND
     sec = ms / 1000
     ms = ms % 1000
@@ -370,6 +367,9 @@ def beautify_length(length):
     Args:
         length (int): The duration in nanoseconds.
     """
+    if length == Gst.CLOCK_TIME_NONE:
+        return ""
+
     sec = length / Gst.SECOND
     mins = int(sec / 60)
     sec = int(sec % 60)
@@ -459,18 +459,21 @@ def model(columns, data):
     return ret
 
 
-def set_combo_value(combo, value, default_index=-1):
-    model = combo.props.model
-    for i, row in enumerate(model):
-        if row[1] == value:
-            combo.set_active(i)
-            return
-    combo.set_active(default_index)
+def set_combo_value(combo, value):
+    def select_specific_row(model, unused_path, iter_, unused_data):
+        if value == model.get_value(iter_, 1):
+            combo.set_active_iter(iter_)
+            return True
+        return False
+
+    combo.props.model.foreach(select_specific_row, None)
 
 
 def get_combo_value(combo):
-    active = combo.get_active()
-    return combo.props.model[active][1]
+    active_iter = combo.get_active_iter()
+    if not active_iter:
+        return None
+    return combo.props.model.get_value(active_iter, 1)
 
 
 def get_value_from_model(model, key):
@@ -491,8 +494,8 @@ def get_value_from_model(model, key):
 
 def alter_style_class(style_class, target_widget, css_style):
     css_provider = Gtk.CssProvider()
-    toolbar_css = "%s { %s }" % (style_class, css_style)
-    css_provider.load_from_data(toolbar_css.encode('UTF-8'))
+    css = "%s { %s }" % (style_class, css_style)
+    css_provider.load_from_data(css.encode('UTF-8'))
     style_context = target_widget.get_style_context()
     style_context.add_provider(
         css_provider, Gtk.STYLE_PROVIDER_PRIORITY_APPLICATION)
